@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: ghc-mtl
-version: 1.0.1.1
-id: ghc-mtl-1.0.1.1-c640bfbf51c0e4e113a7dd6da4780d10
+version: 1.0.1.2
+id: ghc-mtl-1.0.1.2-567b75cd9019760c82fa5fc9316de2f1
 
 license: BSD3
 copyright:
@@ -21,22 +21,22 @@ exposed: True
 exposed-modules: Control.Monad.Ghc
 hidden-modules:
 trusted: False
-import-dirs: /usr/local/lib/ghc/ghc-mtl-1.0.1.1
-library-dirs: /usr/local/lib/ghc/ghc-mtl-1.0.1.1
-hs-libraries: HSghc-mtl-1.0.1.1
+import-dirs: /usr/local/lib/ghc/ghc-mtl-1.0.1.2
+library-dirs: /usr/local/lib/ghc/ghc-mtl-1.0.1.2
+hs-libraries: HSghc-mtl-1.0.1.2
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: MonadCatchIO-mtl-0.3.0.5-8901559f8f89c3c3946fdd839ae54ae8
-         base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
-         ghc-7.4.2-6bf4f6532d6ddd6d9292345f5811b0d5
-         mtl-2.1.2-cf6082d8d4c6758d23401302efadd028
+depends: MonadCatchIO-mtl-0.3.0.5-db87269a14c9e10c4e605bc41f9823f9
+         base-4.6.0.1-d435272bc8de1d17f3a0aacfbd562dbe
+         ghc-7.6.3-9809b0fefd2b7427f85e285fdfdf8d3e
+         mtl-2.1.2-735d9c92b4f214d454fb5168bb1eb6ee
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-ghc-mtl-1.0.1.1/html/ghc-mtl.haddock
-haddock-html: /usr/local/share/doc/hs-ghc-mtl-1.0.1.1/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-ghc-mtl-1.0.1.2/html/ghc-mtl.haddock
+haddock-html: /usr/local/share/doc/hs-ghc-mtl-1.0.1.2/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
